==> selenium-grid-4.17.0.jar: module-info.java <==
module org.seleniumhq.selenium.grid {
    /* static phase */ requires dev.failsafe.core;
    /* static phase */ requires io.netty.buffer;
    /* static phase */ requires io.netty.codec;
    /* static phase */ requires io.netty.codec.http;
    /* static phase */ requires io.netty.common;
    /* static phase */ requires io.netty.handler;
    /* static phase */ requires jtoml;
    requires org.seleniumhq.selenium.manager;
    requires org.seleniumhq.selenium.support;
    /* transitive */ /* static phase */ requires com.google.common;
    /* transitive */ /* static phase */ requires com.graphqljava;
    /* transitive */ /* static phase */ requires io.netty.transport;
    /* transitive */ requires java.logging;
    /* transitive */ requires java.management;
    /* transitive */ /* static phase */ requires jcommander;
    /* transitive */ /* static phase */ requires jeromq;
    /* transitive */ requires org.seleniumhq.selenium.api;
    /* transitive */ requires org.seleniumhq.selenium.http;
    /* transitive */ requires org.seleniumhq.selenium.json;
    /* transitive */ requires org.seleniumhq.selenium.os;
    /* transitive */ requires org.seleniumhq.selenium.remote_driver;

    exports org.openqa.selenium.cli;
    exports org.openqa.selenium.docker;
    exports org.openqa.selenium.docker.internal;
    exports org.openqa.selenium.docker.v1_41;
    exports org.openqa.selenium.events;
    exports org.openqa.selenium.events.local;
    exports org.openqa.selenium.events.zeromq;
    exports org.openqa.selenium.grid;
    exports org.openqa.selenium.grid.commands;
    exports org.openqa.selenium.grid.component;
    exports org.openqa.selenium.grid.config;
    exports org.openqa.selenium.grid.data;
    exports org.openqa.selenium.grid.distributor;
    exports org.openqa.selenium.grid.distributor.config;
    exports org.openqa.selenium.grid.distributor.httpd;
    exports org.openqa.selenium.grid.distributor.local;
    exports org.openqa.selenium.grid.distributor.remote;
    exports org.openqa.selenium.grid.distributor.selector;
    exports org.openqa.selenium.grid.graphql;
    exports org.openqa.selenium.grid.jmx;
    exports org.openqa.selenium.grid.log;
    exports org.openqa.selenium.grid.node;
    exports org.openqa.selenium.grid.node.config;
    exports org.openqa.selenium.grid.node.docker;
    exports org.openqa.selenium.grid.node.httpd;
    exports org.openqa.selenium.grid.node.local;
    exports org.openqa.selenium.grid.node.relay;
    exports org.openqa.selenium.grid.node.remote;
    exports org.openqa.selenium.grid.router;
    exports org.openqa.selenium.grid.router.httpd;
    exports org.openqa.selenium.grid.security;
    exports org.openqa.selenium.grid.server;
    exports org.openqa.selenium.grid.session;
    exports org.openqa.selenium.grid.session.remote;
    exports org.openqa.selenium.grid.sessionmap;
    exports org.openqa.selenium.grid.sessionmap.config;
    exports org.openqa.selenium.grid.sessionmap.httpd;
    exports org.openqa.selenium.grid.sessionmap.local;
    exports org.openqa.selenium.grid.sessionmap.remote;
    exports org.openqa.selenium.grid.sessionqueue;
    exports org.openqa.selenium.grid.sessionqueue.config;
    exports org.openqa.selenium.grid.sessionqueue.httpd;
    exports org.openqa.selenium.grid.sessionqueue.local;
    exports org.openqa.selenium.grid.sessionqueue.remote;
    exports org.openqa.selenium.grid.web;
    exports org.openqa.selenium.netty.server;
    exports org.openqa.selenium.status;

    opens org.openqa.selenium.grid to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.data to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.security to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.server to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.events to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.commands to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.events.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.web to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.jmx to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.router to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.router.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.docker to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.log to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.docker to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.docker.v1_41 to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.docker.internal to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.status to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.relay to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.selector to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.graphql to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.cli to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.netty.server to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.events.zeromq to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.component to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.session.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.session to org.seleniumhq.selenium.json;

    provides CliCommand with CompletionCommand, EventBusCommand, Hub, InfoCommand, Standalone, DistributorServer, NodeServer, RouterServer, SessionMapServer, NewSessionQueueServer;
    provides HasRoles with DistributorFlags, LoggingFlags, NodeFlags, DockerFlags, RelayFlags, RouterFlags, BaseServerFlags, EventBusFlags, SessionMapFlags, NewSessionQueueFlags;

}

==> selenium-grid-4.19.1.jar: module-info.java <==
module org.seleniumhq.selenium.grid {
    /* static phase */ requires dev.failsafe.core;
    /* static phase */ requires io.netty.buffer;
    /* static phase */ requires io.netty.codec;
    /* static phase */ requires io.netty.codec.http;
    /* static phase */ requires io.netty.common;
    /* static phase */ requires io.netty.handler;
    /* static phase */ requires jtoml;
    requires org.seleniumhq.selenium.manager;
    requires org.seleniumhq.selenium.support;
    /* transitive */ /* static phase */ requires com.google.common;
    /* transitive */ /* static phase */ requires com.graphqljava;
    /* transitive */ /* static phase */ requires io.netty.transport;
    /* transitive */ requires java.logging;
    /* transitive */ requires java.management;
    /* transitive */ /* static phase */ requires jcommander;
    /* transitive */ requires org.seleniumhq.selenium.api;
    /* transitive */ requires org.seleniumhq.selenium.http;
    /* transitive */ requires org.seleniumhq.selenium.json;
    /* transitive */ requires org.seleniumhq.selenium.os;
    /* transitive */ requires org.seleniumhq.selenium.remote_driver;
    /* transitive */ /* static phase */ requires org.zeromq.jeromq;

    exports org.openqa.selenium.cli;
    exports org.openqa.selenium.docker;
    exports org.openqa.selenium.docker.internal;
    exports org.openqa.selenium.docker.v1_41;
    exports org.openqa.selenium.events;
    exports org.openqa.selenium.events.local;
    exports org.openqa.selenium.events.zeromq;
    exports org.openqa.selenium.grid;
    exports org.openqa.selenium.grid.commands;
    exports org.openqa.selenium.grid.component;
    exports org.openqa.selenium.grid.config;
    exports org.openqa.selenium.grid.data;
    exports org.openqa.selenium.grid.distributor;
    exports org.openqa.selenium.grid.distributor.config;
    exports org.openqa.selenium.grid.distributor.httpd;
    exports org.openqa.selenium.grid.distributor.local;
    exports org.openqa.selenium.grid.distributor.remote;
    exports org.openqa.selenium.grid.distributor.selector;
    exports org.openqa.selenium.grid.graphql;
    exports org.openqa.selenium.grid.jmx;
    exports org.openqa.selenium.grid.log;
    exports org.openqa.selenium.grid.node;
    exports org.openqa.selenium.grid.node.config;
    exports org.openqa.selenium.grid.node.docker;
    exports org.openqa.selenium.grid.node.httpd;
    exports org.openqa.selenium.grid.node.local;
    exports org.openqa.selenium.grid.node.relay;
    exports org.openqa.selenium.grid.node.remote;
    exports org.openqa.selenium.grid.router;
    exports org.openqa.selenium.grid.router.httpd;
    exports org.openqa.selenium.grid.security;
    exports org.openqa.selenium.grid.server;
    exports org.openqa.selenium.grid.session;
    exports org.openqa.selenium.grid.session.remote;
    exports org.openqa.selenium.grid.sessionmap;
    exports org.openqa.selenium.grid.sessionmap.config;
    exports org.openqa.selenium.grid.sessionmap.httpd;
    exports org.openqa.selenium.grid.sessionmap.local;
    exports org.openqa.selenium.grid.sessionmap.remote;
    exports org.openqa.selenium.grid.sessionqueue;
    exports org.openqa.selenium.grid.sessionqueue.config;
    exports org.openqa.selenium.grid.sessionqueue.httpd;
    exports org.openqa.selenium.grid.sessionqueue.local;
    exports org.openqa.selenium.grid.sessionqueue.remote;
    exports org.openqa.selenium.grid.web;
    exports org.openqa.selenium.netty.server;
    exports org.openqa.selenium.status;

    opens org.openqa.selenium.grid to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.data to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.security to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.server to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.events to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.commands to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.events.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.web to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.jmx to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.router to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.router.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.docker to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.log to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.httpd to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.docker to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.docker.v1_41 to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.docker.internal to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.status to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.relay to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.distributor.selector to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.graphql to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.cli to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.netty.server to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.local to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionqueue.config to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.events.zeromq to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.node to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.sessionmap.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.component to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.session.remote to org.seleniumhq.selenium.json;
    opens org.openqa.selenium.grid.session to org.seleniumhq.selenium.json;

    provides CliCommand with CompletionCommand, EventBusCommand, Hub, InfoCommand, Standalone, DistributorServer, NodeServer, RouterServer, SessionMapServer, NewSessionQueueServer;
    provides HasRoles with DistributorFlags, LoggingFlags, NodeFlags, DockerFlags, RelayFlags, RouterFlags, BaseServerFlags, EventBusFlags, SessionMapFlags, NewSessionQueueFlags;

}
